@@ -3,6 +3,7 @@ from zorm.config import DEBUG
 from time import time
 import logging
 from operator import itemgetter
+from MySQLdb import escape_string
 
 itemgetter0 = itemgetter(0)
 
@@ -190,10 +191,7 @@ class Query(object):
         if DEBUG:
             begin_time = time()
         try:
-            if values:
-                cursor.execute(sql, values)
-            else:
-                cursor.execute(sql)
+            cursor.execute(sql, values)
         except Exception, ex:
             logging.error(
                 '%s\n%s\nException: %s'%(
@@ -205,7 +203,7 @@ class Query(object):
             logging.info(
                  '%.2f\n\t%s ;'%(
                     1000*(time() - begin_time),
-                    sql.strip()%tuple(values)
+                    sql.strip()%tuple(map(escape_string,values))
                 )
             )
         return cursor
